
#line 1 "cfg_parser.rl"
/*
 * Copyright (C) 2012-2013, Eric Wong <normalperson@yhbt.net>
 * License: GPLv3 or later (see COPYING for details)
 */
/*
 * parses config files used by the original (Perl) mogstored
 */
#include "cmogstored.h"
#include "cfg.h"
#include "listen_parser.h"

static char *mystrdup(const char *key, char *mark_beg, const char *p)
{
	size_t mark_len = p - mark_beg;
	mark_beg[mark_len] = 0;
	if (strlen(mark_beg) != mark_len) {
		syslog(LOG_ERR, "NUL character in `%s' value", key);
		return NULL;
	}

	return xstrdup(mark_beg);
}


#line 117 "cfg_parser.rl"



#line 32 "cfg_parser.c"
static const int cfg_parser_start = 1;
static const int cfg_parser_first_final = 136;
static const int cfg_parser_error = 0;

static const int cfg_parser_en_ignored_line = 135;
static const int cfg_parser_en_main = 1;


#line 120 "cfg_parser.rl"

/* this is a one-shot parser, no need to stream local config files  */
int mog_cfg_parse(struct mog_cfg *cfg, char *buf, size_t len)
{
	char *p, *pe, *eof = NULL;
	char *mark_beg = NULL;
	char *port_beg = NULL;
	size_t mark_len = 0;
	size_t port_len = 0;
	sa_family_t sa_family = AF_INET;
	struct mog_addrinfo *a;
	int cs;

	
#line 56 "cfg_parser.c"
	{
	cs = cfg_parser_start;
	}

#line 134 "cfg_parser.rl"

	p = buf;
	pe = buf + len;

	
#line 67 "cfg_parser.c"
	{
	if ( p == pe )
		goto _test_eof;
	switch ( cs )
	{
st1:
	if ( ++p == pe )
		goto _test_eof1;
case 1:
	switch( (*p) ) {
		case 9: goto st1;
		case 32: goto st1;
		case 100: goto st2;
		case 104: goto st13;
		case 109: goto st62;
		case 112: goto st98;
		case 115: goto st108;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st1;
	goto tr0;
tr0:
#line 113 "cfg_parser.rl"
	{
			p--;
			{goto st135;}
		}
	goto st0;
tr34:
#line 23 "listen_parser_common.rl"
	{
		syslog(LOG_ERR, "bad character in IP address: %c", (*p));
	}
#line 113 "cfg_parser.rl"
	{
			p--;
			{goto st135;}
		}
	goto st0;
#line 107 "cfg_parser.c"
st0:
cs = 0;
	goto _out;
st2:
	if ( ++p == pe )
		goto _test_eof2;
case 2:
	switch( (*p) ) {
		case 97: goto st3;
		case 111: goto st126;
	}
	goto tr0;
st3:
	if ( ++p == pe )
		goto _test_eof3;
case 3:
	if ( (*p) == 101 )
		goto st4;
	goto tr0;
st4:
	if ( ++p == pe )
		goto _test_eof4;
case 4:
	if ( (*p) == 109 )
		goto st5;
	goto tr0;
st5:
	if ( ++p == pe )
		goto _test_eof5;
case 5:
	if ( (*p) == 111 )
		goto st6;
	goto tr0;
st6:
	if ( ++p == pe )
		goto _test_eof6;
case 6:
	if ( (*p) == 110 )
		goto st7;
	goto tr0;
st7:
	if ( ++p == pe )
		goto _test_eof7;
case 7:
	if ( (*p) == 105 )
		goto st8;
	goto tr0;
st8:
	if ( ++p == pe )
		goto _test_eof8;
case 8:
	if ( (*p) == 122 )
		goto st9;
	goto tr0;
st9:
	if ( ++p == pe )
		goto _test_eof9;
case 9:
	if ( (*p) == 101 )
		goto st10;
	goto tr0;
st10:
	if ( ++p == pe )
		goto _test_eof10;
case 10:
	switch( (*p) ) {
		case 10: goto tr17;
		case 32: goto st11;
		case 35: goto st12;
		case 61: goto st123;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto st11;
	goto tr0;
st11:
	if ( ++p == pe )
		goto _test_eof11;
case 11:
	switch( (*p) ) {
		case 9: goto st11;
		case 32: goto st11;
		case 35: goto st12;
		case 61: goto st123;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st11;
	goto tr0;
st12:
	if ( ++p == pe )
		goto _test_eof12;
case 12:
	if ( (*p) == 10 )
		goto tr17;
	goto st12;
tr17:
#line 66 "cfg_parser.rl"
	{
		syslog(LOG_ERR,
"\"daemonize\" in was supported in error in the past and now deprecated");
		syslog(LOG_ERR,
"use \"daemonize = 1\" in your config file instead");
		cfg->daemonize = true;
	}
	goto st136;
tr39:
#line 50 "cfg_parser.rl"
	{
		a = mog_listen_parse_internal(mark_beg, mark_len,
		                              port_beg, port_len, sa_family);
		if (!a) return -1;
		cfg->httpgetlisten = a;
	}
	goto st136;
tr63:
#line 44 "cfg_parser.rl"
	{
		a = mog_listen_parse_internal(mark_beg, mark_len,
		                              port_beg, port_len, sa_family);
		if (!a) return -1;
		cfg->httplisten = a;
	}
	goto st136;
tr88:
#line 84 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;
			errno = 0;
			cfg->maxconns = strtoul(mark_beg, NULL, 10);
			if (errno) {
				syslog(LOG_ERR,
				       "failed to parse: maxconns = %s - %m",
				       mark_beg);
				return -1;
			}
		}
	goto st136;
tr107:
#line 37 "cfg_parser.rl"
	{
		a = mog_listen_parse_internal(mark_beg, mark_len,
		                              port_beg, port_len, sa_family);
		if (!a) return -1;
		cfg->mgmtlisten = a;
	}
	goto st136;
tr131:
#line 61 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->pidfile = mystrdup("pidfile", mark_beg, p);
		if (!cfg->pidfile) return -1;
	}
	goto st136;
tr145:
#line 98 "cfg_parser.rl"
	{
			cfg->server = mystrdup("server", mark_beg, p);
			if (!cfg->server) return -1;
			mog_cfg_check_server(cfg);
		}
	goto st136;
tr154:
#line 104 "cfg_parser.rl"
	{
			char *tmp = mystrdup("serverbin", mark_beg, p);
			if (!tmp) return -1;
			warn("W: serverbin = %s ignored", tmp);
			free(tmp);
		}
	goto st136;
tr161:
#line 75 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;

			/* special case for compatibility with mogstored */
			cfg->daemonize = strcmp("0", mark_beg);
		}
	goto st136;
tr174:
#line 56 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->docroot = mystrdup("docroot", mark_beg, p);
		if (!cfg->docroot) return -1;
	}
	goto st136;
st136:
	if ( ++p == pe )
		goto _test_eof136;
case 136:
#line 301 "cfg_parser.c"
	switch( (*p) ) {
		case 9: goto st1;
		case 32: goto st1;
		case 100: goto st2;
		case 104: goto st13;
		case 109: goto st62;
		case 112: goto st98;
		case 115: goto st108;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st1;
	goto tr0;
st13:
	if ( ++p == pe )
		goto _test_eof13;
case 13:
	if ( (*p) == 116 )
		goto st14;
	goto tr0;
st14:
	if ( ++p == pe )
		goto _test_eof14;
case 14:
	if ( (*p) == 116 )
		goto st15;
	goto tr0;
st15:
	if ( ++p == pe )
		goto _test_eof15;
case 15:
	if ( (*p) == 112 )
		goto st16;
	goto tr0;
st16:
	if ( ++p == pe )
		goto _test_eof16;
case 16:
	switch( (*p) ) {
		case 103: goto st17;
		case 108: goto st41;
	}
	goto tr0;
st17:
	if ( ++p == pe )
		goto _test_eof17;
case 17:
	if ( (*p) == 101 )
		goto st18;
	goto tr0;
st18:
	if ( ++p == pe )
		goto _test_eof18;
case 18:
	if ( (*p) == 116 )
		goto st19;
	goto tr0;
st19:
	if ( ++p == pe )
		goto _test_eof19;
case 19:
	if ( (*p) == 108 )
		goto st20;
	goto tr0;
st20:
	if ( ++p == pe )
		goto _test_eof20;
case 20:
	if ( (*p) == 105 )
		goto st21;
	goto tr0;
st21:
	if ( ++p == pe )
		goto _test_eof21;
case 21:
	if ( (*p) == 115 )
		goto st22;
	goto tr0;
st22:
	if ( ++p == pe )
		goto _test_eof22;
case 22:
	if ( (*p) == 116 )
		goto st23;
	goto tr0;
st23:
	if ( ++p == pe )
		goto _test_eof23;
case 23:
	if ( (*p) == 101 )
		goto st24;
	goto tr0;
st24:
	if ( ++p == pe )
		goto _test_eof24;
case 24:
	if ( (*p) == 110 )
		goto st25;
	goto tr0;
st25:
	if ( ++p == pe )
		goto _test_eof25;
case 25:
	switch( (*p) ) {
		case 9: goto st25;
		case 32: goto st25;
		case 61: goto st26;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st25;
	goto tr0;
st26:
	if ( ++p == pe )
		goto _test_eof26;
case 26:
	switch( (*p) ) {
		case 9: goto st26;
		case 32: goto st26;
		case 58: goto st36;
		case 91: goto st38;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr35;
	} else if ( (*p) >= 11 )
		goto st26;
	goto tr34;
tr35:
#line 9 "listen_parser_common.rl"
	{ mark_beg = p; }
#line 20 "listen_parser_common.rl"
	{ port_beg = p; }
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st27;
tr42:
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st27;
st27:
	if ( ++p == pe )
		goto _test_eof27;
case 27:
#line 444 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr39;
		case 32: goto st28;
		case 35: goto st29;
		case 46: goto st30;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr42;
	} else if ( (*p) >= 9 )
		goto st28;
	goto tr34;
st28:
	if ( ++p == pe )
		goto _test_eof28;
case 28:
	switch( (*p) ) {
		case 9: goto st28;
		case 32: goto st28;
		case 35: goto st29;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st28;
	goto tr0;
st29:
	if ( ++p == pe )
		goto _test_eof29;
case 29:
	if ( (*p) == 10 )
		goto tr39;
	goto st29;
st30:
	if ( ++p == pe )
		goto _test_eof30;
case 30:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st31;
	goto tr34;
st31:
	if ( ++p == pe )
		goto _test_eof31;
case 31:
	if ( (*p) == 46 )
		goto st32;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st31;
	goto tr34;
st32:
	if ( ++p == pe )
		goto _test_eof32;
case 32:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st33;
	goto tr34;
st33:
	if ( ++p == pe )
		goto _test_eof33;
case 33:
	if ( (*p) == 46 )
		goto st34;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st33;
	goto tr34;
st34:
	if ( ++p == pe )
		goto _test_eof34;
case 34:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr47;
	goto tr34;
tr47:
#line 10 "listen_parser_common.rl"
	{
			mark_len = p - mark_beg + 1;
			sa_family = AF_INET;
		}
	goto st35;
st35:
	if ( ++p == pe )
		goto _test_eof35;
case 35:
#line 526 "cfg_parser.c"
	if ( (*p) == 58 )
		goto st36;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr47;
	goto tr34;
st36:
	if ( ++p == pe )
		goto _test_eof36;
case 36:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr48;
	goto tr34;
tr49:
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st37;
tr48:
#line 20 "listen_parser_common.rl"
	{ port_beg = p; }
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st37;
st37:
	if ( ++p == pe )
		goto _test_eof37;
case 37:
#line 553 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr39;
		case 32: goto st28;
		case 35: goto st29;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr49;
	} else if ( (*p) >= 9 )
		goto st28;
	goto tr34;
st38:
	if ( ++p == pe )
		goto _test_eof38;
case 38:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr50;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr50;
	} else
		goto tr50;
	goto tr34;
tr50:
#line 16 "listen_parser_common.rl"
	{ mark_beg = p; }
#line 17 "listen_parser_common.rl"
	{ mark_len = p - mark_beg + 1; }
	goto st39;
tr51:
#line 17 "listen_parser_common.rl"
	{ mark_len = p - mark_beg + 1; }
	goto st39;
st39:
	if ( ++p == pe )
		goto _test_eof39;
case 39:
#line 592 "cfg_parser.c"
	if ( (*p) == 93 )
		goto tr52;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr51;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr51;
	} else
		goto tr51;
	goto tr34;
tr52:
#line 18 "listen_parser_common.rl"
	{ sa_family = AF_INET6; }
	goto st40;
st40:
	if ( ++p == pe )
		goto _test_eof40;
case 40:
#line 612 "cfg_parser.c"
	if ( (*p) == 58 )
		goto st36;
	goto tr34;
st41:
	if ( ++p == pe )
		goto _test_eof41;
case 41:
	if ( (*p) == 105 )
		goto st42;
	goto tr0;
st42:
	if ( ++p == pe )
		goto _test_eof42;
case 42:
	if ( (*p) == 115 )
		goto st43;
	goto tr0;
st43:
	if ( ++p == pe )
		goto _test_eof43;
case 43:
	if ( (*p) == 116 )
		goto st44;
	goto tr0;
st44:
	if ( ++p == pe )
		goto _test_eof44;
case 44:
	if ( (*p) == 101 )
		goto st45;
	goto tr0;
st45:
	if ( ++p == pe )
		goto _test_eof45;
case 45:
	if ( (*p) == 110 )
		goto st46;
	goto tr0;
st46:
	if ( ++p == pe )
		goto _test_eof46;
case 46:
	switch( (*p) ) {
		case 9: goto st46;
		case 32: goto st46;
		case 61: goto st47;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st46;
	goto tr0;
st47:
	if ( ++p == pe )
		goto _test_eof47;
case 47:
	switch( (*p) ) {
		case 9: goto st47;
		case 32: goto st47;
		case 58: goto st57;
		case 91: goto st59;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr59;
	} else if ( (*p) >= 11 )
		goto st47;
	goto tr34;
tr59:
#line 9 "listen_parser_common.rl"
	{ mark_beg = p; }
#line 20 "listen_parser_common.rl"
	{ port_beg = p; }
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st48;
tr66:
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st48;
st48:
	if ( ++p == pe )
		goto _test_eof48;
case 48:
#line 695 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr63;
		case 32: goto st49;
		case 35: goto st50;
		case 46: goto st51;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr66;
	} else if ( (*p) >= 9 )
		goto st49;
	goto tr34;
st49:
	if ( ++p == pe )
		goto _test_eof49;
case 49:
	switch( (*p) ) {
		case 9: goto st49;
		case 32: goto st49;
		case 35: goto st50;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st49;
	goto tr0;
st50:
	if ( ++p == pe )
		goto _test_eof50;
case 50:
	if ( (*p) == 10 )
		goto tr63;
	goto st50;
st51:
	if ( ++p == pe )
		goto _test_eof51;
case 51:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st52;
	goto tr34;
st52:
	if ( ++p == pe )
		goto _test_eof52;
case 52:
	if ( (*p) == 46 )
		goto st53;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st52;
	goto tr34;
st53:
	if ( ++p == pe )
		goto _test_eof53;
case 53:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st54;
	goto tr34;
st54:
	if ( ++p == pe )
		goto _test_eof54;
case 54:
	if ( (*p) == 46 )
		goto st55;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st54;
	goto tr34;
st55:
	if ( ++p == pe )
		goto _test_eof55;
case 55:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr71;
	goto tr34;
tr71:
#line 10 "listen_parser_common.rl"
	{
			mark_len = p - mark_beg + 1;
			sa_family = AF_INET;
		}
	goto st56;
st56:
	if ( ++p == pe )
		goto _test_eof56;
case 56:
#line 777 "cfg_parser.c"
	if ( (*p) == 58 )
		goto st57;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr71;
	goto tr34;
st57:
	if ( ++p == pe )
		goto _test_eof57;
case 57:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr72;
	goto tr34;
tr73:
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st58;
tr72:
#line 20 "listen_parser_common.rl"
	{ port_beg = p; }
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st58;
st58:
	if ( ++p == pe )
		goto _test_eof58;
case 58:
#line 804 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr63;
		case 32: goto st49;
		case 35: goto st50;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr73;
	} else if ( (*p) >= 9 )
		goto st49;
	goto tr34;
st59:
	if ( ++p == pe )
		goto _test_eof59;
case 59:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr74;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr74;
	} else
		goto tr74;
	goto tr34;
tr74:
#line 16 "listen_parser_common.rl"
	{ mark_beg = p; }
#line 17 "listen_parser_common.rl"
	{ mark_len = p - mark_beg + 1; }
	goto st60;
tr75:
#line 17 "listen_parser_common.rl"
	{ mark_len = p - mark_beg + 1; }
	goto st60;
st60:
	if ( ++p == pe )
		goto _test_eof60;
case 60:
#line 843 "cfg_parser.c"
	if ( (*p) == 93 )
		goto tr76;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr75;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr75;
	} else
		goto tr75;
	goto tr34;
tr76:
#line 18 "listen_parser_common.rl"
	{ sa_family = AF_INET6; }
	goto st61;
st61:
	if ( ++p == pe )
		goto _test_eof61;
case 61:
#line 863 "cfg_parser.c"
	if ( (*p) == 58 )
		goto st57;
	goto tr34;
st62:
	if ( ++p == pe )
		goto _test_eof62;
case 62:
	switch( (*p) ) {
		case 97: goto st63;
		case 103: goto st74;
	}
	goto tr0;
st63:
	if ( ++p == pe )
		goto _test_eof63;
case 63:
	if ( (*p) == 120 )
		goto st64;
	goto tr0;
st64:
	if ( ++p == pe )
		goto _test_eof64;
case 64:
	if ( (*p) == 99 )
		goto st65;
	goto tr0;
st65:
	if ( ++p == pe )
		goto _test_eof65;
case 65:
	if ( (*p) == 111 )
		goto st66;
	goto tr0;
st66:
	if ( ++p == pe )
		goto _test_eof66;
case 66:
	if ( (*p) == 110 )
		goto st67;
	goto tr0;
st67:
	if ( ++p == pe )
		goto _test_eof67;
case 67:
	if ( (*p) == 110 )
		goto st68;
	goto tr0;
st68:
	if ( ++p == pe )
		goto _test_eof68;
case 68:
	if ( (*p) == 115 )
		goto st69;
	goto tr0;
st69:
	if ( ++p == pe )
		goto _test_eof69;
case 69:
	switch( (*p) ) {
		case 9: goto st69;
		case 32: goto st69;
		case 61: goto st70;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st69;
	goto tr0;
st70:
	if ( ++p == pe )
		goto _test_eof70;
case 70:
	switch( (*p) ) {
		case 9: goto st70;
		case 32: goto st70;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr86;
	} else if ( (*p) >= 11 )
		goto st70;
	goto tr0;
tr86:
#line 83 "cfg_parser.rl"
	{ mark_beg = p; }
	goto st71;
st71:
	if ( ++p == pe )
		goto _test_eof71;
case 71:
#line 952 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr88;
		case 32: goto tr87;
		case 35: goto tr89;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto st71;
	} else if ( (*p) >= 9 )
		goto tr87;
	goto tr0;
tr87:
#line 84 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;
			errno = 0;
			cfg->maxconns = strtoul(mark_beg, NULL, 10);
			if (errno) {
				syslog(LOG_ERR,
				       "failed to parse: maxconns = %s - %m",
				       mark_beg);
				return -1;
			}
		}
	goto st72;
tr130:
#line 61 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->pidfile = mystrdup("pidfile", mark_beg, p);
		if (!cfg->pidfile) return -1;
	}
	goto st72;
tr144:
#line 98 "cfg_parser.rl"
	{
			cfg->server = mystrdup("server", mark_beg, p);
			if (!cfg->server) return -1;
			mog_cfg_check_server(cfg);
		}
	goto st72;
tr153:
#line 104 "cfg_parser.rl"
	{
			char *tmp = mystrdup("serverbin", mark_beg, p);
			if (!tmp) return -1;
			warn("W: serverbin = %s ignored", tmp);
			free(tmp);
		}
	goto st72;
tr160:
#line 75 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;

			/* special case for compatibility with mogstored */
			cfg->daemonize = strcmp("0", mark_beg);
		}
	goto st72;
tr173:
#line 56 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->docroot = mystrdup("docroot", mark_beg, p);
		if (!cfg->docroot) return -1;
	}
	goto st72;
st72:
	if ( ++p == pe )
		goto _test_eof72;
case 72:
#line 1026 "cfg_parser.c"
	switch( (*p) ) {
		case 9: goto st72;
		case 32: goto st72;
		case 35: goto st73;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st72;
	goto tr0;
tr89:
#line 84 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;
			errno = 0;
			cfg->maxconns = strtoul(mark_beg, NULL, 10);
			if (errno) {
				syslog(LOG_ERR,
				       "failed to parse: maxconns = %s - %m",
				       mark_beg);
				return -1;
			}
		}
	goto st73;
tr134:
#line 61 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->pidfile = mystrdup("pidfile", mark_beg, p);
		if (!cfg->pidfile) return -1;
	}
	goto st73;
tr146:
#line 98 "cfg_parser.rl"
	{
			cfg->server = mystrdup("server", mark_beg, p);
			if (!cfg->server) return -1;
			mog_cfg_check_server(cfg);
		}
	goto st73;
tr157:
#line 104 "cfg_parser.rl"
	{
			char *tmp = mystrdup("serverbin", mark_beg, p);
			if (!tmp) return -1;
			warn("W: serverbin = %s ignored", tmp);
			free(tmp);
		}
	goto st73;
tr164:
#line 75 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;

			/* special case for compatibility with mogstored */
			cfg->daemonize = strcmp("0", mark_beg);
		}
	goto st73;
tr177:
#line 56 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->docroot = mystrdup("docroot", mark_beg, p);
		if (!cfg->docroot) return -1;
	}
	goto st73;
st73:
	if ( ++p == pe )
		goto _test_eof73;
case 73:
#line 1097 "cfg_parser.c"
	if ( (*p) == 10 )
		goto st136;
	goto st73;
st74:
	if ( ++p == pe )
		goto _test_eof74;
case 74:
	if ( (*p) == 109 )
		goto st75;
	goto tr0;
st75:
	if ( ++p == pe )
		goto _test_eof75;
case 75:
	if ( (*p) == 116 )
		goto st76;
	goto tr0;
st76:
	if ( ++p == pe )
		goto _test_eof76;
case 76:
	if ( (*p) == 108 )
		goto st77;
	goto tr0;
st77:
	if ( ++p == pe )
		goto _test_eof77;
case 77:
	if ( (*p) == 105 )
		goto st78;
	goto tr0;
st78:
	if ( ++p == pe )
		goto _test_eof78;
case 78:
	if ( (*p) == 115 )
		goto st79;
	goto tr0;
st79:
	if ( ++p == pe )
		goto _test_eof79;
case 79:
	if ( (*p) == 116 )
		goto st80;
	goto tr0;
st80:
	if ( ++p == pe )
		goto _test_eof80;
case 80:
	if ( (*p) == 101 )
		goto st81;
	goto tr0;
st81:
	if ( ++p == pe )
		goto _test_eof81;
case 81:
	if ( (*p) == 110 )
		goto st82;
	goto tr0;
st82:
	if ( ++p == pe )
		goto _test_eof82;
case 82:
	switch( (*p) ) {
		case 9: goto st82;
		case 32: goto st82;
		case 61: goto st83;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st82;
	goto tr0;
st83:
	if ( ++p == pe )
		goto _test_eof83;
case 83:
	switch( (*p) ) {
		case 9: goto st83;
		case 32: goto st83;
		case 58: goto st93;
		case 91: goto st95;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr103;
	} else if ( (*p) >= 11 )
		goto st83;
	goto tr34;
tr103:
#line 9 "listen_parser_common.rl"
	{ mark_beg = p; }
#line 20 "listen_parser_common.rl"
	{ port_beg = p; }
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st84;
tr110:
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st84;
st84:
	if ( ++p == pe )
		goto _test_eof84;
case 84:
#line 1201 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr107;
		case 32: goto st85;
		case 35: goto st86;
		case 46: goto st87;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr110;
	} else if ( (*p) >= 9 )
		goto st85;
	goto tr34;
st85:
	if ( ++p == pe )
		goto _test_eof85;
case 85:
	switch( (*p) ) {
		case 9: goto st85;
		case 32: goto st85;
		case 35: goto st86;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st85;
	goto tr0;
st86:
	if ( ++p == pe )
		goto _test_eof86;
case 86:
	if ( (*p) == 10 )
		goto tr107;
	goto st86;
st87:
	if ( ++p == pe )
		goto _test_eof87;
case 87:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st88;
	goto tr34;
st88:
	if ( ++p == pe )
		goto _test_eof88;
case 88:
	if ( (*p) == 46 )
		goto st89;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st88;
	goto tr34;
st89:
	if ( ++p == pe )
		goto _test_eof89;
case 89:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st90;
	goto tr34;
st90:
	if ( ++p == pe )
		goto _test_eof90;
case 90:
	if ( (*p) == 46 )
		goto st91;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto st90;
	goto tr34;
st91:
	if ( ++p == pe )
		goto _test_eof91;
case 91:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr115;
	goto tr34;
tr115:
#line 10 "listen_parser_common.rl"
	{
			mark_len = p - mark_beg + 1;
			sa_family = AF_INET;
		}
	goto st92;
st92:
	if ( ++p == pe )
		goto _test_eof92;
case 92:
#line 1283 "cfg_parser.c"
	if ( (*p) == 58 )
		goto st93;
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr115;
	goto tr34;
st93:
	if ( ++p == pe )
		goto _test_eof93;
case 93:
	if ( 48 <= (*p) && (*p) <= 57 )
		goto tr116;
	goto tr34;
tr117:
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st94;
tr116:
#line 20 "listen_parser_common.rl"
	{ port_beg = p; }
#line 21 "listen_parser_common.rl"
	{ port_len = p - port_beg + 1; }
	goto st94;
st94:
	if ( ++p == pe )
		goto _test_eof94;
case 94:
#line 1310 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr107;
		case 32: goto st85;
		case 35: goto st86;
	}
	if ( (*p) > 13 ) {
		if ( 48 <= (*p) && (*p) <= 57 )
			goto tr117;
	} else if ( (*p) >= 9 )
		goto st85;
	goto tr34;
st95:
	if ( ++p == pe )
		goto _test_eof95;
case 95:
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr118;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr118;
	} else
		goto tr118;
	goto tr34;
tr118:
#line 16 "listen_parser_common.rl"
	{ mark_beg = p; }
#line 17 "listen_parser_common.rl"
	{ mark_len = p - mark_beg + 1; }
	goto st96;
tr119:
#line 17 "listen_parser_common.rl"
	{ mark_len = p - mark_beg + 1; }
	goto st96;
st96:
	if ( ++p == pe )
		goto _test_eof96;
case 96:
#line 1349 "cfg_parser.c"
	if ( (*p) == 93 )
		goto tr120;
	if ( (*p) < 65 ) {
		if ( 48 <= (*p) && (*p) <= 58 )
			goto tr119;
	} else if ( (*p) > 70 ) {
		if ( 97 <= (*p) && (*p) <= 102 )
			goto tr119;
	} else
		goto tr119;
	goto tr34;
tr120:
#line 18 "listen_parser_common.rl"
	{ sa_family = AF_INET6; }
	goto st97;
st97:
	if ( ++p == pe )
		goto _test_eof97;
case 97:
#line 1369 "cfg_parser.c"
	if ( (*p) == 58 )
		goto st93;
	goto tr34;
st98:
	if ( ++p == pe )
		goto _test_eof98;
case 98:
	if ( (*p) == 105 )
		goto st99;
	goto tr0;
st99:
	if ( ++p == pe )
		goto _test_eof99;
case 99:
	if ( (*p) == 100 )
		goto st100;
	goto tr0;
st100:
	if ( ++p == pe )
		goto _test_eof100;
case 100:
	if ( (*p) == 102 )
		goto st101;
	goto tr0;
st101:
	if ( ++p == pe )
		goto _test_eof101;
case 101:
	if ( (*p) == 105 )
		goto st102;
	goto tr0;
st102:
	if ( ++p == pe )
		goto _test_eof102;
case 102:
	if ( (*p) == 108 )
		goto st103;
	goto tr0;
st103:
	if ( ++p == pe )
		goto _test_eof103;
case 103:
	if ( (*p) == 101 )
		goto st104;
	goto tr0;
st104:
	if ( ++p == pe )
		goto _test_eof104;
case 104:
	switch( (*p) ) {
		case 9: goto st104;
		case 32: goto st104;
		case 61: goto st105;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st104;
	goto tr0;
st105:
	if ( ++p == pe )
		goto _test_eof105;
case 105:
	switch( (*p) ) {
		case 10: goto tr0;
		case 32: goto st105;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto st105;
	goto tr128;
tr128:
#line 35 "cfg_parser.rl"
	{ mark_beg = p; }
	goto st106;
st106:
	if ( ++p == pe )
		goto _test_eof106;
case 106:
#line 1446 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr131;
		case 32: goto tr130;
		case 35: goto tr132;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr130;
	goto st106;
tr132:
#line 61 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->pidfile = mystrdup("pidfile", mark_beg, p);
		if (!cfg->pidfile) return -1;
	}
	goto st107;
st107:
	if ( ++p == pe )
		goto _test_eof107;
case 107:
#line 1467 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr131;
		case 32: goto tr134;
		case 35: goto tr132;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr134;
	goto st107;
st108:
	if ( ++p == pe )
		goto _test_eof108;
case 108:
	if ( (*p) == 101 )
		goto st109;
	goto tr0;
st109:
	if ( ++p == pe )
		goto _test_eof109;
case 109:
	if ( (*p) == 114 )
		goto st110;
	goto tr0;
st110:
	if ( ++p == pe )
		goto _test_eof110;
case 110:
	if ( (*p) == 118 )
		goto st111;
	goto tr0;
st111:
	if ( ++p == pe )
		goto _test_eof111;
case 111:
	if ( (*p) == 101 )
		goto st112;
	goto tr0;
st112:
	if ( ++p == pe )
		goto _test_eof112;
case 112:
	if ( (*p) == 114 )
		goto st113;
	goto tr0;
st113:
	if ( ++p == pe )
		goto _test_eof113;
case 113:
	switch( (*p) ) {
		case 9: goto st114;
		case 32: goto st114;
		case 61: goto st115;
		case 98: goto st117;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st114;
	goto tr0;
st114:
	if ( ++p == pe )
		goto _test_eof114;
case 114:
	switch( (*p) ) {
		case 9: goto st114;
		case 32: goto st114;
		case 61: goto st115;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st114;
	goto tr0;
st115:
	if ( ++p == pe )
		goto _test_eof115;
case 115:
	switch( (*p) ) {
		case 9: goto st115;
		case 32: goto st115;
	}
	if ( (*p) < 65 ) {
		if ( 11 <= (*p) && (*p) <= 13 )
			goto st115;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto tr143;
	} else
		goto tr143;
	goto tr0;
tr143:
#line 97 "cfg_parser.rl"
	{ mark_beg = p; }
	goto st116;
st116:
	if ( ++p == pe )
		goto _test_eof116;
case 116:
#line 1561 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr145;
		case 32: goto tr144;
		case 35: goto tr146;
	}
	if ( (*p) < 65 ) {
		if ( 9 <= (*p) && (*p) <= 13 )
			goto tr144;
	} else if ( (*p) > 90 ) {
		if ( 97 <= (*p) && (*p) <= 122 )
			goto st116;
	} else
		goto st116;
	goto tr0;
st117:
	if ( ++p == pe )
		goto _test_eof117;
case 117:
	if ( (*p) == 105 )
		goto st118;
	goto tr0;
st118:
	if ( ++p == pe )
		goto _test_eof118;
case 118:
	if ( (*p) == 110 )
		goto st119;
	goto tr0;
st119:
	if ( ++p == pe )
		goto _test_eof119;
case 119:
	switch( (*p) ) {
		case 9: goto st119;
		case 32: goto st119;
		case 61: goto st120;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st119;
	goto tr0;
st120:
	if ( ++p == pe )
		goto _test_eof120;
case 120:
	switch( (*p) ) {
		case 10: goto tr0;
		case 32: goto st120;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto st120;
	goto tr151;
tr151:
#line 35 "cfg_parser.rl"
	{ mark_beg = p; }
	goto st121;
st121:
	if ( ++p == pe )
		goto _test_eof121;
case 121:
#line 1621 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr154;
		case 32: goto tr153;
		case 35: goto tr155;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr153;
	goto st121;
tr155:
#line 104 "cfg_parser.rl"
	{
			char *tmp = mystrdup("serverbin", mark_beg, p);
			if (!tmp) return -1;
			warn("W: serverbin = %s ignored", tmp);
			free(tmp);
		}
	goto st122;
st122:
	if ( ++p == pe )
		goto _test_eof122;
case 122:
#line 1643 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr154;
		case 32: goto tr157;
		case 35: goto tr155;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr157;
	goto st122;
st123:
	if ( ++p == pe )
		goto _test_eof123;
case 123:
	switch( (*p) ) {
		case 10: goto tr0;
		case 32: goto st123;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto st123;
	goto tr158;
tr158:
#line 74 "cfg_parser.rl"
	{ mark_beg = p; }
	goto st124;
st124:
	if ( ++p == pe )
		goto _test_eof124;
case 124:
#line 1671 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr161;
		case 32: goto tr160;
		case 35: goto tr162;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr160;
	goto st124;
tr162:
#line 75 "cfg_parser.rl"
	{
			mark_len = p - mark_beg;
			mark_beg[mark_len] = 0;

			/* special case for compatibility with mogstored */
			cfg->daemonize = strcmp("0", mark_beg);
		}
	goto st125;
st125:
	if ( ++p == pe )
		goto _test_eof125;
case 125:
#line 1694 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr161;
		case 32: goto tr164;
		case 35: goto tr162;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr164;
	goto st125;
st126:
	if ( ++p == pe )
		goto _test_eof126;
case 126:
	if ( (*p) == 99 )
		goto st127;
	goto tr0;
st127:
	if ( ++p == pe )
		goto _test_eof127;
case 127:
	if ( (*p) == 114 )
		goto st128;
	goto tr0;
st128:
	if ( ++p == pe )
		goto _test_eof128;
case 128:
	if ( (*p) == 111 )
		goto st129;
	goto tr0;
st129:
	if ( ++p == pe )
		goto _test_eof129;
case 129:
	if ( (*p) == 111 )
		goto st130;
	goto tr0;
st130:
	if ( ++p == pe )
		goto _test_eof130;
case 130:
	if ( (*p) == 116 )
		goto st131;
	goto tr0;
st131:
	if ( ++p == pe )
		goto _test_eof131;
case 131:
	switch( (*p) ) {
		case 9: goto st131;
		case 32: goto st131;
		case 61: goto st132;
	}
	if ( 11 <= (*p) && (*p) <= 13 )
		goto st131;
	goto tr0;
st132:
	if ( ++p == pe )
		goto _test_eof132;
case 132:
	switch( (*p) ) {
		case 10: goto tr0;
		case 32: goto st132;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto st132;
	goto tr171;
tr171:
#line 35 "cfg_parser.rl"
	{ mark_beg = p; }
	goto st133;
st133:
	if ( ++p == pe )
		goto _test_eof133;
case 133:
#line 1769 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr174;
		case 32: goto tr173;
		case 35: goto tr175;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr173;
	goto st133;
tr175:
#line 56 "cfg_parser.rl"
	{
		/* delay realpath(3) until svc init, symlinks may change */
		cfg->docroot = mystrdup("docroot", mark_beg, p);
		if (!cfg->docroot) return -1;
	}
	goto st134;
st134:
	if ( ++p == pe )
		goto _test_eof134;
case 134:
#line 1790 "cfg_parser.c"
	switch( (*p) ) {
		case 10: goto tr174;
		case 32: goto tr177;
		case 35: goto tr175;
	}
	if ( 9 <= (*p) && (*p) <= 13 )
		goto tr177;
	goto st134;
st135:
	if ( ++p == pe )
		goto _test_eof135;
case 135:
	if ( (*p) == 10 )
		goto tr179;
	goto st135;
tr179:
#line 29 "cfg_parser.rl"
	{ {goto st1;} }
	goto st137;
st137:
	if ( ++p == pe )
		goto _test_eof137;
case 137:
#line 1814 "cfg_parser.c"
	goto st0;
	}
	_test_eof1: cs = 1; goto _test_eof; 
	_test_eof2: cs = 2; goto _test_eof; 
	_test_eof3: cs = 3; goto _test_eof; 
	_test_eof4: cs = 4; goto _test_eof; 
	_test_eof5: cs = 5; goto _test_eof; 
	_test_eof6: cs = 6; goto _test_eof; 
	_test_eof7: cs = 7; goto _test_eof; 
	_test_eof8: cs = 8; goto _test_eof; 
	_test_eof9: cs = 9; goto _test_eof; 
	_test_eof10: cs = 10; goto _test_eof; 
	_test_eof11: cs = 11; goto _test_eof; 
	_test_eof12: cs = 12; goto _test_eof; 
	_test_eof136: cs = 136; goto _test_eof; 
	_test_eof13: cs = 13; goto _test_eof; 
	_test_eof14: cs = 14; goto _test_eof; 
	_test_eof15: cs = 15; goto _test_eof; 
	_test_eof16: cs = 16; goto _test_eof; 
	_test_eof17: cs = 17; goto _test_eof; 
	_test_eof18: cs = 18; goto _test_eof; 
	_test_eof19: cs = 19; goto _test_eof; 
	_test_eof20: cs = 20; goto _test_eof; 
	_test_eof21: cs = 21; goto _test_eof; 
	_test_eof22: cs = 22; goto _test_eof; 
	_test_eof23: cs = 23; goto _test_eof; 
	_test_eof24: cs = 24; goto _test_eof; 
	_test_eof25: cs = 25; goto _test_eof; 
	_test_eof26: cs = 26; goto _test_eof; 
	_test_eof27: cs = 27; goto _test_eof; 
	_test_eof28: cs = 28; goto _test_eof; 
	_test_eof29: cs = 29; goto _test_eof; 
	_test_eof30: cs = 30; goto _test_eof; 
	_test_eof31: cs = 31; goto _test_eof; 
	_test_eof32: cs = 32; goto _test_eof; 
	_test_eof33: cs = 33; goto _test_eof; 
	_test_eof34: cs = 34; goto _test_eof; 
	_test_eof35: cs = 35; goto _test_eof; 
	_test_eof36: cs = 36; goto _test_eof; 
	_test_eof37: cs = 37; goto _test_eof; 
	_test_eof38: cs = 38; goto _test_eof; 
	_test_eof39: cs = 39; goto _test_eof; 
	_test_eof40: cs = 40; goto _test_eof; 
	_test_eof41: cs = 41; goto _test_eof; 
	_test_eof42: cs = 42; goto _test_eof; 
	_test_eof43: cs = 43; goto _test_eof; 
	_test_eof44: cs = 44; goto _test_eof; 
	_test_eof45: cs = 45; goto _test_eof; 
	_test_eof46: cs = 46; goto _test_eof; 
	_test_eof47: cs = 47; goto _test_eof; 
	_test_eof48: cs = 48; goto _test_eof; 
	_test_eof49: cs = 49; goto _test_eof; 
	_test_eof50: cs = 50; goto _test_eof; 
	_test_eof51: cs = 51; goto _test_eof; 
	_test_eof52: cs = 52; goto _test_eof; 
	_test_eof53: cs = 53; goto _test_eof; 
	_test_eof54: cs = 54; goto _test_eof; 
	_test_eof55: cs = 55; goto _test_eof; 
	_test_eof56: cs = 56; goto _test_eof; 
	_test_eof57: cs = 57; goto _test_eof; 
	_test_eof58: cs = 58; goto _test_eof; 
	_test_eof59: cs = 59; goto _test_eof; 
	_test_eof60: cs = 60; goto _test_eof; 
	_test_eof61: cs = 61; goto _test_eof; 
	_test_eof62: cs = 62; goto _test_eof; 
	_test_eof63: cs = 63; goto _test_eof; 
	_test_eof64: cs = 64; goto _test_eof; 
	_test_eof65: cs = 65; goto _test_eof; 
	_test_eof66: cs = 66; goto _test_eof; 
	_test_eof67: cs = 67; goto _test_eof; 
	_test_eof68: cs = 68; goto _test_eof; 
	_test_eof69: cs = 69; goto _test_eof; 
	_test_eof70: cs = 70; goto _test_eof; 
	_test_eof71: cs = 71; goto _test_eof; 
	_test_eof72: cs = 72; goto _test_eof; 
	_test_eof73: cs = 73; goto _test_eof; 
	_test_eof74: cs = 74; goto _test_eof; 
	_test_eof75: cs = 75; goto _test_eof; 
	_test_eof76: cs = 76; goto _test_eof; 
	_test_eof77: cs = 77; goto _test_eof; 
	_test_eof78: cs = 78; goto _test_eof; 
	_test_eof79: cs = 79; goto _test_eof; 
	_test_eof80: cs = 80; goto _test_eof; 
	_test_eof81: cs = 81; goto _test_eof; 
	_test_eof82: cs = 82; goto _test_eof; 
	_test_eof83: cs = 83; goto _test_eof; 
	_test_eof84: cs = 84; goto _test_eof; 
	_test_eof85: cs = 85; goto _test_eof; 
	_test_eof86: cs = 86; goto _test_eof; 
	_test_eof87: cs = 87; goto _test_eof; 
	_test_eof88: cs = 88; goto _test_eof; 
	_test_eof89: cs = 89; goto _test_eof; 
	_test_eof90: cs = 90; goto _test_eof; 
	_test_eof91: cs = 91; goto _test_eof; 
	_test_eof92: cs = 92; goto _test_eof; 
	_test_eof93: cs = 93; goto _test_eof; 
	_test_eof94: cs = 94; goto _test_eof; 
	_test_eof95: cs = 95; goto _test_eof; 
	_test_eof96: cs = 96; goto _test_eof; 
	_test_eof97: cs = 97; goto _test_eof; 
	_test_eof98: cs = 98; goto _test_eof; 
	_test_eof99: cs = 99; goto _test_eof; 
	_test_eof100: cs = 100; goto _test_eof; 
	_test_eof101: cs = 101; goto _test_eof; 
	_test_eof102: cs = 102; goto _test_eof; 
	_test_eof103: cs = 103; goto _test_eof; 
	_test_eof104: cs = 104; goto _test_eof; 
	_test_eof105: cs = 105; goto _test_eof; 
	_test_eof106: cs = 106; goto _test_eof; 
	_test_eof107: cs = 107; goto _test_eof; 
	_test_eof108: cs = 108; goto _test_eof; 
	_test_eof109: cs = 109; goto _test_eof; 
	_test_eof110: cs = 110; goto _test_eof; 
	_test_eof111: cs = 111; goto _test_eof; 
	_test_eof112: cs = 112; goto _test_eof; 
	_test_eof113: cs = 113; goto _test_eof; 
	_test_eof114: cs = 114; goto _test_eof; 
	_test_eof115: cs = 115; goto _test_eof; 
	_test_eof116: cs = 116; goto _test_eof; 
	_test_eof117: cs = 117; goto _test_eof; 
	_test_eof118: cs = 118; goto _test_eof; 
	_test_eof119: cs = 119; goto _test_eof; 
	_test_eof120: cs = 120; goto _test_eof; 
	_test_eof121: cs = 121; goto _test_eof; 
	_test_eof122: cs = 122; goto _test_eof; 
	_test_eof123: cs = 123; goto _test_eof; 
	_test_eof124: cs = 124; goto _test_eof; 
	_test_eof125: cs = 125; goto _test_eof; 
	_test_eof126: cs = 126; goto _test_eof; 
	_test_eof127: cs = 127; goto _test_eof; 
	_test_eof128: cs = 128; goto _test_eof; 
	_test_eof129: cs = 129; goto _test_eof; 
	_test_eof130: cs = 130; goto _test_eof; 
	_test_eof131: cs = 131; goto _test_eof; 
	_test_eof132: cs = 132; goto _test_eof; 
	_test_eof133: cs = 133; goto _test_eof; 
	_test_eof134: cs = 134; goto _test_eof; 
	_test_eof135: cs = 135; goto _test_eof; 
	_test_eof137: cs = 137; goto _test_eof; 

	_test_eof: {}
	if ( p == eof )
	{
	switch ( cs ) {
	case 1: 
	case 2: 
	case 3: 
	case 4: 
	case 5: 
	case 6: 
	case 7: 
	case 8: 
	case 9: 
	case 10: 
	case 11: 
	case 12: 
	case 13: 
	case 14: 
	case 15: 
	case 16: 
	case 17: 
	case 18: 
	case 19: 
	case 20: 
	case 21: 
	case 22: 
	case 23: 
	case 24: 
	case 25: 
	case 28: 
	case 29: 
	case 41: 
	case 42: 
	case 43: 
	case 44: 
	case 45: 
	case 46: 
	case 49: 
	case 50: 
	case 62: 
	case 63: 
	case 64: 
	case 65: 
	case 66: 
	case 67: 
	case 68: 
	case 69: 
	case 70: 
	case 71: 
	case 72: 
	case 73: 
	case 74: 
	case 75: 
	case 76: 
	case 77: 
	case 78: 
	case 79: 
	case 80: 
	case 81: 
	case 82: 
	case 85: 
	case 86: 
	case 98: 
	case 99: 
	case 100: 
	case 101: 
	case 102: 
	case 103: 
	case 104: 
	case 105: 
	case 106: 
	case 107: 
	case 108: 
	case 109: 
	case 110: 
	case 111: 
	case 112: 
	case 113: 
	case 114: 
	case 115: 
	case 116: 
	case 117: 
	case 118: 
	case 119: 
	case 120: 
	case 121: 
	case 122: 
	case 123: 
	case 124: 
	case 125: 
	case 126: 
	case 127: 
	case 128: 
	case 129: 
	case 130: 
	case 131: 
	case 132: 
	case 133: 
	case 134: 
#line 113 "cfg_parser.rl"
	{
			p--;
			{goto st135;}
		}
	break;
	case 26: 
	case 27: 
	case 30: 
	case 31: 
	case 32: 
	case 33: 
	case 34: 
	case 35: 
	case 36: 
	case 37: 
	case 38: 
	case 39: 
	case 40: 
	case 47: 
	case 48: 
	case 51: 
	case 52: 
	case 53: 
	case 54: 
	case 55: 
	case 56: 
	case 57: 
	case 58: 
	case 59: 
	case 60: 
	case 61: 
	case 83: 
	case 84: 
	case 87: 
	case 88: 
	case 89: 
	case 90: 
	case 91: 
	case 92: 
	case 93: 
	case 94: 
	case 95: 
	case 96: 
	case 97: 
#line 23 "listen_parser_common.rl"
	{
		syslog(LOG_ERR, "bad character in IP address: %c", (*p));
	}
#line 113 "cfg_parser.rl"
	{
			p--;
			{goto st135;}
		}
	break;
#line 2109 "cfg_parser.c"
	}
	}

	_out: {}
	}

#line 139 "cfg_parser.rl"

	if (cs == cfg_parser_error)
		return -1;

	assert(p <= pe && "buffer overflow after cfg parse");
	return 0;
}
